plot() is a generic function designed for visualizing
various aspects of statistical models. It provides a unified
interface for generating plots that vary depending on the
model type and the specific method implemented for that
model class.
Details
Current available method:
lavaanCFA and SEM models:plot.lavaan()for plotting factor loadings and other metrics for models from thelavaanpackage.
Future methods may include support for:
Exploratory Factor Analysis: Models from the
psychpackage.Item Response Theory (IRT): Models from the
mirtpackage.
See also
plot.lavaan() for lavaan objects